@@ -1,3 +1,5 @@
+from typing import Union
+
 from pydantic import BaseModel
 from pydantic.fields import Field
 
@@ -9,6 +11,6 @@ class Bill(BaseModel):
     """
 
     id: int = Field(..., alias='pay_id')
-    transaction_id: int | None = None
+    transaction_id: Union[int, None] = None
     status: str = 'waiting'
     url: str = Field(..., alias='payment_url')
